# pytest-pings

🦊 The pytest plugin for Firefox Telemetry 📊

## Development

🚧 This project is under active development. Do not use it in production. ⚠️

## Community

Please note that **pytest-pings** is released with a [Contributor Code of
Conduct][code of conduct]. By participating in this project you agree to
abide by its terms.

[code of conduct]: https://github.com/hackebrot/pytest-pings/blob/master/.github/CODE_OF_CONDUCT.md

## License

This project is distributed under the terms of the [Mozilla Public License
2.0][license].

[license]: https://github.com/hackebrot/pytest-pings/blob/master/LICENSE
